@@ -51,8 +51,9 @@ type Issue struct {
 	Priority                string `gorm:"type:varchar(255)"`
 	Severity                string `gorm:"type:varchar(255)"`
 	Urgency                 string `gorm:"type:varchar(255)"`
-	Component               string `gorm:"type:varchar(255)"`
+	Component               string `gorm:"type:text"`
 	OriginalProject         string `gorm:"type:varchar(255)"`
+	IsSubtask               bool
 }
 
 func (Issue) TableName() string {
@@ -105,3 +106,48 @@ func GetStatus(rule *StatusRule, input interface{}) string {
 	}
 	return rule.Default
 }
+
+func (issue Issue) IsIncident() bool {
+	return issue.Type == INCIDENT
+}
+
+func (issue Issue) ToIncidentAssignee() (*IncidentAssignee, error) {
+	return &IncidentAssignee{
+		IncidentId:   issue.Id,
+		AssigneeId:   issue.AssigneeId,
+		AssigneeName: issue.AssigneeName,
+		NoPKModel:    issue.DomainEntity.NoPKModel,
+	}, nil
+}
+
+func (issue Issue) ToIncident(boardId string) (*Incident, error) {
+	incident := &Incident{
+		DomainEntity:            issue.DomainEntity,
+		Url:                     issue.Url,
+		IncidentKey:             issue.IssueKey,
+		Title:                   issue.Title,
+		Description:             issue.Description,
+		Status:                  issue.Status,
+		OriginalStatus:          issue.OriginalStatus,
+		ResolutionDate:          issue.ResolutionDate,
+		CreatedDate:             issue.CreatedDate,
+		UpdatedDate:             issue.UpdatedDate,
+		LeadTimeMinutes:         issue.LeadTimeMinutes,
+		OriginalEstimateMinutes: issue.OriginalEstimateMinutes,
+		TimeSpentMinutes:        issue.TimeSpentMinutes,
+		TimeRemainingMinutes:    issue.TimeRemainingMinutes,
+		CreatorId:               issue.CreatorId,
+		CreatorName:             issue.CreatorName,
+		ParentIncidentId:        issue.ParentIssueId,
+		Priority:                issue.Priority,
+		Severity:                issue.Severity,
+		Urgency:                 issue.Urgency,
+		Component:               issue.Component,
+		OriginalProject:         issue.OriginalProject,
+		ScopeId:                 boardId,
+		Table:                   "boards",
+		AssigneeId:              issue.AssigneeId,
+		AssigneeName:            issue.AssigneeName,
+	}
+	return incident, nil
+}
