@@ -121,5 +121,16 @@ func All() []plugin.MigrationScript {
 		new(modifyCicdPipelineCommitsRepoUrlLength),
 		new(addPrAssigneeAndReviewer),
 		new(modifyPrAssigneeAndReviewerId),
+		new(addChangesToPr),
+		new(addMergedByToPr),
+		new(addPullRequestIdIndexToPullRequestCommits),
+		new(addPullRequestIdIndexToPullRequestComments),
+		new(addIsDraftToPr),
+		new(initIncidentRelatedTables),
+		new(renameProjectIssueMetrics),
+		new(addDateFieldsToProjectPrMetric),
+		new(addTableScopeIdToIncident),
+		new(addAssigneeToIncident),
+		new(addIsSubtaskToIssue),
 	}
 }
