@@ -18,6 +18,8 @@ limitations under the License.
 package tasks
 
 import (
+	"reflect"
+
 	"github.com/apache/incubator-devlake/core/dal"
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/code"
@@ -25,7 +27,6 @@ import (
 	"github.com/apache/incubator-devlake/core/plugin"
 	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 	"github.com/apache/incubator-devlake/plugins/gitlab/models"
-	"reflect"
 )
 
 func init() {
@@ -33,7 +34,7 @@ func init() {
 }
 
 var ConvertCommitsMeta = plugin.SubTaskMeta{
-	Name:             "convertApiCommits",
+	Name:             "Convert Commits",
 	EntryPoint:       ConvertApiCommits,
 	EnabledByDefault: false,
 	Description:      "Update domain layer commit according to GitlabCommit",
