@@ -49,5 +49,9 @@ func All() []plugin.MigrationScript {
 		new(addFilterJQL),
 		new(addWorklogToIssue),
 		new(addSubtaskToIssue),
+		new(addTmpAccountIdToJiraIssueChangelogItem),
+		new(addIssueFieldTable),
+		new(changeIssueComponentType),
+		new(flushJiraIssues),
 	}
 }
