@@ -24,7 +24,7 @@ import (
 type User struct {
 	common.NoPKModel
 	ConnectionId uint64 `gorm:"primaryKey"`
-	Id           string `gorm:"primaryKey"`
+	Id           string `gorm:"primaryKey;autoIncrement:false"`
 	Url          string
 	Name         string
 }
