@@ -18,19 +18,20 @@ limitations under the License.
 package models
 
 import (
-	"encoding/json"
-
 	"github.com/apache/incubator-devlake/core/models/common"
 )
 
 type TapdScopeConfig struct {
 	common.ScopeConfig `mapstructure:",squash" json:",inline" gorm:"embedded"`
-	ConnectionId       uint64          `mapstructure:"connectionId" json:"connectionId"`
-	Name               string          `gorm:"type:varchar(255);index:idx_name_tapd,unique" validate:"required" mapstructure:"name" json:"name"`
-	TypeMappings       json.RawMessage `mapstructure:"typeMappings,omitempty" json:"typeMappings"`
-	StatusMappings     json.RawMessage `mapstructure:"statusMappings,omitempty" json:"statusMappings"`
+	TypeMappings       map[string]string `mapstructure:"typeMappings,omitempty" json:"typeMappings" gorm:"serializer:json"`
+	StatusMappings     map[string]string `mapstructure:"statusMappings,omitempty" json:"statusMappings" gorm:"serializer:json"`
 }
 
 func (t TapdScopeConfig) TableName() string {
 	return "_tool_tapd_scope_configs"
 }
+
+func (t *TapdScopeConfig) SetConnectionId(c *TapdScopeConfig, connectionId uint64) {
+	c.ConnectionId = connectionId
+	c.ScopeConfig.ConnectionId = connectionId
+}
