@@ -18,7 +18,7 @@
 
 import { useEffect, useState } from 'react';
 import { useNavigate } from 'react-router-dom';
-import { Flex, Space, Card, Modal, Input, Checkbox, Button, message } from 'antd';
+import { Flex, Space, Card, Modal, Input, Checkbox, Button } from 'antd';
 
 import API from '@/api';
 import { Block, HelpTooltip, Message } from '@/components';
@@ -26,8 +26,6 @@ import { PATHS } from '@/config';
 import { IProject } from '@/types';
 import { operator } from '@/utils';
 
-import { validName } from '../utils';
-
 import * as S from './styled';
 
 const RegexPrIssueDefaultValue = '(?mi)(Closes)[\\s]*.*(((and )?#\\d+[ ]*)+)';
@@ -46,6 +44,9 @@ export const SettingsPanel = ({ project, onRefresh }: Props) => {
     enable: false,
     prToIssueRegexp: '',
   });
+  const [issueTrace, setIssueTrace] = useState({
+    enable: false,
+  });
   const [operating, setOperating] = useState(false);
   const [open, setOpen] = useState(false);
 
@@ -54,6 +55,7 @@ export const SettingsPanel = ({ project, onRefresh }: Props) => {
   useEffect(() => {
     const dora = project.metrics.find((ms) => ms.pluginName === 'dora');
     const linker = project.metrics.find((ms) => ms.pluginName === 'linker');
+    const issueTrace = project.metrics.find((ms) => ms.pluginName === 'issue_trace');
 
     setName(project.name);
     setDora({
@@ -63,14 +65,12 @@ export const SettingsPanel = ({ project, onRefresh }: Props) => {
       enable: linker?.enable ?? false,
       prToIssueRegexp: linker?.pluginOption?.prToIssueRegexp ?? RegexPrIssueDefaultValue,
     });
+    setIssueTrace({
+      enable: issueTrace?.enable ?? false,
+    });
   }, [project]);
 
   const handleUpdate = async () => {
-    if (!validName(name)) {
-      message.error('Please enter alphanumeric or underscore');
-      return;
-    }
-
     const [success] = await operator(
       () =>
         API.project.update(project.name, {
@@ -89,6 +89,11 @@ export const SettingsPanel = ({ project, onRefresh }: Props) => {
               },
               enable: linker.enable,
             },
+            {
+              pluginName: 'issue_trace',
+              pluginOption: {},
+              enable: issueTrace.enable,
+            },
           ],
         }),
       {
@@ -98,7 +103,11 @@ export const SettingsPanel = ({ project, onRefresh }: Props) => {
 
     if (success) {
       onRefresh();
-      navigate(PATHS.PROJECT(name, { tabId: 'settings' }));
+      navigate(PATHS.PROJECT(name), {
+        state: {
+          tabId: 'settings',
+        },
+      });
     }
   };
 
@@ -174,6 +183,14 @@ export const SettingsPanel = ({ project, onRefresh }: Props) => {
               />
             )}
           </Block>
+          <Block
+            title={
+              <Checkbox checked={issueTrace.enable} onChange={(e) => setIssueTrace({ enable: e.target.checked })}>
+                Enable issue trace
+              </Checkbox>
+            }
+            description="Parse the issue status and assignee history from issue changelogs. Currently, only Jira issues are supported."
+          />
           <Block>
             <Button type="primary" loading={operating} disabled={!name} onClick={handleUpdate}>
               Save
